function [timestamp, sen_val, data]=ubidots_get(tokenID,variableID,num_data)
// Retrieve data with other information as well from Ubidots sensor's variable
//
// Syntax
//    [timestamp, sen_val, data] = ubidots_get(tokenID,sensorID,num_data)
//
// Parameters
//     tokenID : Token ID
//     sensorID : Sensor ID
//     num_data : Numbers of data to get from the sensor's variable, maximum 300
//     timestamp : Time stamp in unix time milliseconds
//     sen_val : Sensor data
//     data : Structure of full details, always not required 
//
// Description
//    Get data to Ubidots sensor's variable. As this function will return all the details for each sensors data, the maximum data could be retrived by this function is 300. To get all data with only timestamp and value, use ubidots_getdata instead.
//
// See also
//    ubidots_getdata
//    ubidots_count
//    ubidots_listsource
//    ubidots_listvar
//    ubidots_post
//
// Authors
//     Joshua T., C.L. Tan, Bytecode    
//    
    
    rhs=argn(2);
    if rhs < 2; error('At least 2 inputs required : tokenID,variableID' ); end  
    if rhs < 3; num_data = 10; end  
    
    if num_data >= 300 then
        num_data = 300;
    end
   
   // Send request 
   str = 'http://things.ubidots.com/api/v1.6/variables/' + variableID + '/values?page_size=' + string(num_data) + '&token=' + tokenID
   
   [result,status]=http_get(str);
    
    if  status ~=200 then
        timestamp = []
        sen_val = []
        data = [];
        if typeof(result) == "st"
            if isfield(result,"detail")
                error(msprintf("Error! Status: %d, Details: %s\n",status,result.detail))
            else
                error(msprintf("Error! Status: %d\n",status))
            end
        else
            error(msprintf("Error! Please check tokenID or variableID."))
        end
                
    elseif status ==200 then
        //Extract timestamp
        timestamp = list2vec(result.results.timestamp)
        timestamp = timestamp($:-1:1);
        
        // Extract values
        sen_val = list2vec(result.results.value);
        sen_val = sen_val($:-1:1);
        
        // Extract created_at
        create = list2vec(result.results.created_at)
        create=create($:-1:1);
        
        // Extract context
        context = list2vec(result.results.context)
        context = context($:-1:1);
        if typeof(context) == "st"
            if sum(fieldnames(context)) == 0
                context = emptystr(size(context,'*'),1)
            end
        end
    
        
        
        // Store in struct
        data=struct("timestamp",timestamp,"created_at",create,"context",context,"value",sen_val)
           
    end
endfunction
