function [timestamp, var_val]=ubidots_getdata(tokenID,variableID,num_data)
// Retrieve data with timestamp from Ubidots sensor's variable
//
// Syntax
//    [timestamp, sen_val, data] = ubidots_get(tokenID,sensorID,num_data)
//
// Parameters
//     tokenID : Token ID
//     sensorID : Sensor ID
//     num_data : Numbers of data to get from the sensor's variable
//     timestamp : Time stamp in unix time milliseconds
//     sen_val : Sensor data
//
// Description
//    Get all data to Ubidots sensor's variable. This function will only return the timestamp and sensor value but no other details. 
//
// See also
//    ubidots_get
//    ubidots_count
//    ubidots_listsource
//    ubidots_listvar
//    ubidots_post 
//
// Authors
//     Joshua T., C.L. Tan, Bytecode 
//
    
    
    rhs=argn(2);
    if rhs < 2; error('At least 2 inputs required : tokenID,variableID' ); end  
    if rhs < 3; num_data = 10; end  
   
   // Send request
   str = 'http://things.ubidots.com/api/v1.6/variables/' + variableID + '/values?page_size=' + string(num_data) + '&token=' + tokenID

   [result,status]=http_get(str)
    
    if  status ~=200 then
        timestamp = []
        var_val = []
        if typeof(result) == "st"
            if isfield(result,"detail")
                error(msprintf("Error! Status: %d, Details: %s\n",status,result.detail))
            else
                error(msprintf("Error! Status: %d\n",status))
            end
        else
            error(msprintf("Error! Please check tokenID or variableID."))
        end
       
                
    elseif status ==200 then
        //Extract timestamp
        timestamp = list2vec(result.results.timestamp)
        timestamp = timestamp($:-1:1);
        
        // Extract values
        var_val = list2vec(result.results.value);
        var_val = var_val($:-1:1);
           
    end
endfunction
